==> migrate_wizard-1.0.8-alpha1.tar.gz: migrate_wizard/src/Plugin/migrate/process/SocialMediaLinks.php <==
<?php

namespace Drupal\migrate_wizard\Plugin\migrate\process;

use Drupal\link\Plugin\migrate\process\FieldLink;
use Drupal\migrate\MigrateExecutableInterface;
use Drupal\migrate\Row;

/**
 * Transform a pre-Drupal 8 formatted link for use in Drupal 8.
 *
 * Previous to Drupal 8, URLs didn't need to have a URI scheme assigned. The
 * contrib link module would auto-prefix the URL with a URI scheme. A link in
 * Drupal 8 has more validation and external links must include the URI scheme.
 * All external URIs need to be converted to use a URI scheme.
 *
 * Available configuration keys
 * - uri_scheme: (optional) The URI scheme prefix to use for URLs without a
 *   scheme. Defaults to 'http://', which was the default in Drupal 6 and
 *   Drupal 7.
 *
 * Examples:
 *
 * Consider a link field migration, where you want to use https:// as the
 * prefix:
 *
 * @code
 * process:
 *   field_link:
 *     plugin: field_link_value
 *     uri_scheme: 'https://'
 *     source: field_link
 * @endcode
 *
 * @MigrateProcessPlugin(
 *   id = "social_media_links"
 * )
 */
class SocialMediaLinks extends FieldLink {

  /**
   * {@inheritdoc}
   */
  public function transform($value, MigrateExecutableInterface $migrate_executable, Row $row, $destination_property) {

    $social_link_field_plugin_manager = \Drupal::service('plugin.manager.social_link_field.platform');
    $plugins = $social_link_field_plugin_manager->getPlatforms();

    $url = parse_url($value, PHP_URL_SCHEME) . '://' . parse_url($value, PHP_URL_HOST);

    $array_values = ['link' => str_replace($url, '', $value)];

    foreach ($plugins as $key_plugin => $plugin) {
      if (strpos($value, $key_plugin)) {
        $array_values['social'] = $key_plugin;
        break;
      }
    }

    return $array_values;
  }

}

==> migrate_wizard-2.0.2-alpha1.tar.gz: migrate_wizard/src/Plugin/migrate/process/SocialMediaLinks.php <==
<?php

namespace Drupal\migrate_wizard\Plugin\migrate\process;

use Drupal\link\Plugin\migrate\process\FieldLink;
use Drupal\migrate\MigrateExecutableInterface;
use Drupal\migrate\Row;

/**
 * Transform a pre-Drupal 8 formatted link for use in Drupal 8.
 *
 * Previous to Drupal 8, URLs didn't need to have a URI scheme assigned. The
 * contrib link module would auto-prefix the URL with a URI scheme. A link in
 * Drupal 8 has more validation and external links must include the URI scheme.
 * All external URIs need to be converted to use a URI scheme.
 *
 * Available configuration keys
 * - uri_scheme: (optional) The URI scheme prefix to use for URLs without a
 *   scheme. Defaults to 'http://', which was the default in Drupal 6 and
 *   Drupal 7.
 *
 * Examples:
 *
 * Consider a link field migration, where you want to use https:// as the
 * prefix:
 *
 * @code
 * process:
 *   field_link:
 *     plugin: field_link_value
 *     uri_scheme: 'https://'
 *     source: field_link
 * @endcode
 *
 * @MigrateProcessPlugin(
 *   id = "social_media_links"
 * )
 */
class SocialMediaLinks extends FieldLink {

  /**
   * {@inheritdoc}
   */
  public function transform($value, MigrateExecutableInterface $migrate_executable, Row $row, $destination_property) {

    $social_link_field_plugin_manager = \Drupal::service('plugin.manager.social_link_field.platform');
    $plugins = $social_link_field_plugin_manager->getPlatforms();

    $url = parse_url($value['url'], PHP_URL_SCHEME) . '://' . parse_url($value['url'], PHP_URL_HOST);

    $array_values = ['link' => str_replace($url, '', $value['url'])];

    foreach ($plugins as $key_plugin => $plugin) {
      if (strpos($value['url'], $key_plugin)) {
        $array_values['social'] = $key_plugin;
        break;
      }
    }

    return $array_values;
  }

}
